==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *  The remote virtual network should be in the same region. See here to learn more (https://docs.microsoft.com/en-us/azure/databricks/administration-guide/cloud-configurations/azure/vnet-peering).
 * @property id The Id of the databricks virtual network.
 */
public data class VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs(
    public val id: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs> {
    override fun toJava():
        com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs =
        com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs].
 */
@PulumiTagMarker
public class VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgsBuilder internal
constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The Id of the databricks virtual network.
     */
    @JvmName("oqhucunpswcesooo")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The Id of the databricks virtual network.
     */
    @JvmName("xcmhjmdmqspwrtnw")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs =
        VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs(
            id = id,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *  The remote virtual network should be in the same region. See here to learn more (https://docs.microsoft.com/en-us/azure/databricks/administration-guide/cloud-configurations/azure/vnet-peering).
 * @property id The Id of the databricks virtual network.
 */
public data class VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs(
    public val id: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs> {
    override fun toJava():
        com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs =
        com.pulumi.azurenative.databricks.inputs.VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs].
 */
@PulumiTagMarker
public class VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgsBuilder internal
constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The Id of the databricks virtual network.
     */
    @JvmName("spkdxqwlutxldkkh")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The Id of the databricks virtual network.
     */
    @JvmName("pkxevswvinsehiwc")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs =
        VirtualNetworkPeeringPropertiesFormatDatabricksVirtualNetworkArgs(
            id = id,
        )
}
